@@ -1,31 +1,30 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*-
  * gtksourcecompletionwordsbuffer.c
- * This file is part of gtksourceview
+ * This file is part of GtkSourceView
  *
  * Copyright (C) 2009 - Jesse van den Kieboom
  *
- * gtksourceview is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * gtksourceview is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * gtksourceview is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with gtksourceview; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "gtksourcecompletionwordsbuffer.h"
 #include "gtksourcecompletionwordsutils.h"
 
-#include <glib/gprintf.h>
+#include <glib.h>
 
-#define GTK_SOURCE_COMPLETION_WORDS_BUFFER_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GTK_TYPE_SOURCE_COMPLETION_WORDS_BUFFER, GtkSourceCompletionWordsBufferPrivate))
+#define GTK_SOURCE_COMPLETION_WORDS_BUFFER_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GTK_SOURCE_TYPE_COMPLETION_WORDS_BUFFER, GtkSourceCompletionWordsBufferPrivate))
 
 /* Timeout in seconds */
 #define INITIATE_SCAN_TIMEOUT 5
@@ -524,11 +523,6 @@ add_scan_region (GtkSourceCompletionWordsBuffer *buffer,
 			                      next,
 			                      region);
 	}
-	else
-	{
-		GList *ignore;
-		ignore = g_list_append (next, region);
-	}
 
 	/* Add the initate scan timeout if it's not already running */
 	install_initiate_scan (buffer);
@@ -605,7 +599,11 @@ remove_and_rescan (GtkSourceCompletionWordsBuffer *buffer,
 		else if (gtk_text_iter_compare (&startc, &region_end) < 0)
 		{
 			startc = region_end;
-			gtk_text_iter_forward_line (&startc);
+
+			if (!gtk_text_iter_forward_line (&startc))
+			{
+				return;
+			}
 		}
 
 		if (gtk_text_iter_compare (&startc, &endc) > 0)
@@ -732,10 +730,10 @@ gtk_source_completion_words_buffer_new (GtkSourceCompletionWordsLibrary *library
 	GtkSourceCompletionWordsBuffer *ret;
 	GtkTextIter iter;
 
-	g_return_val_if_fail (GTK_IS_SOURCE_COMPLETION_WORDS_LIBRARY (library), NULL);
+	g_return_val_if_fail (GTK_SOURCE_IS_COMPLETION_WORDS_LIBRARY (library), NULL);
 	g_return_val_if_fail (GTK_IS_TEXT_BUFFER (buffer), NULL);
 
-	ret = g_object_new (GTK_TYPE_SOURCE_COMPLETION_WORDS_BUFFER, NULL);
+	ret = g_object_new (GTK_SOURCE_TYPE_COMPLETION_WORDS_BUFFER, NULL);
 
 	ret->priv->library = g_object_ref (library);
 	ret->priv->buffer = g_object_ref (buffer);
@@ -763,7 +761,7 @@ gtk_source_completion_words_buffer_new (GtkSourceCompletionWordsLibrary *library
 GtkTextBuffer *
 gtk_source_completion_words_buffer_get_buffer (GtkSourceCompletionWordsBuffer *buffer)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_COMPLETION_WORDS_BUFFER (buffer), NULL);
+	g_return_val_if_fail (GTK_SOURCE_IS_COMPLETION_WORDS_BUFFER (buffer), NULL);
 
 	return buffer->priv->buffer;
 }
@@ -772,7 +770,7 @@ void
 gtk_source_completion_words_buffer_set_scan_batch_size (GtkSourceCompletionWordsBuffer *buffer,
                                                         guint                           size)
 {
-	g_return_if_fail (GTK_IS_SOURCE_COMPLETION_WORDS_BUFFER (buffer));
+	g_return_if_fail (GTK_SOURCE_IS_COMPLETION_WORDS_BUFFER (buffer));
 	g_return_if_fail (size != 0);
 
 	buffer->priv->scan_batch_size = size;
@@ -782,7 +780,7 @@ void
 gtk_source_completion_words_buffer_set_minimum_word_size (GtkSourceCompletionWordsBuffer *buffer,
                                                           guint                           size)
 {
-	g_return_if_fail (GTK_IS_SOURCE_COMPLETION_WORDS_BUFFER (buffer));
+	g_return_if_fail (GTK_SOURCE_IS_COMPLETION_WORDS_BUFFER (buffer));
 	g_return_if_fail (size != 0);
 
 	buffer->priv->minimum_word_size = size;
@@ -791,7 +789,7 @@ gtk_source_completion_words_buffer_set_minimum_word_size (GtkSourceCompletionWor
 GtkTextMark *
 gtk_source_completion_words_buffer_get_mark (GtkSourceCompletionWordsBuffer *buffer)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_COMPLETION_WORDS_BUFFER (buffer), NULL);
+	g_return_val_if_fail (GTK_SOURCE_IS_COMPLETION_WORDS_BUFFER (buffer), NULL);
 
 	return buffer->priv->mark;
 }
